player = {}

-- Constructor
function player:new()
	-- parameter hier
	local object = {
		x = 			0,
		y = 			0,
		w = 			0,
		h = 			0,
		xVelocity = 	0,
		yVelocity = 	0,
		state = 		"",
		jumpVelocity = 	0,
		xSpeed =		0,
		ySpeed =		0,
		jumpSpeed = 	0,
    hopSpeed = 0,
		runSpeed = 		0,
    col,
    sprite = love.graphics.newImage("assets/sprites/player/idle.png"),
		canJump =		false,
    canHop = false
	}
	setmetatable(object, { __index = player })
	return object
end

-- Movement functions
function player:jump()
	if self.canJump then
		self.ySpeed = self.jumpSpeed
		self.canJump = false
	end
end

function player:hop()
	if self.canHop then
		self.ySpeed = self.hopSpeed
		self.canHop = false
	end
end

function player:moveRight(dt)
  self:hop()
	self.xSpeed = self.runSpeed + dt
	self.state = "moveRight"
  self.sprite = love.graphics.newImage("assets/sprites/player/right.png")
end

function player:moveLeft(dt)
  self:hop()
	self.xSpeed = -1 * (self.runSpeed) + dt
	self.state = "moveLeft"
  self.sprite = love.graphics.newImage("assets/sprites/player/left.png")
end

function player:stop()
	self.xSpeed = 0
  self.sprite = love.graphics.newImage("assets/sprites/player/idle.png")
end

function player:hitFloor(maxY)
  self.y = maxY - self.h
  self.ySpeed = 0
  self.canJump = true
  self.canHop = true
end

-- Update function
function player:update(dt, gravity)
	-- update players position
	self.x = self.x + (self.xSpeed * dt)
	self.y = self.y + (self.ySpeed * dt)
	
	-- apply gravity
	self.ySpeed = self.ySpeed + (gravity * dt)
	
	-- update players state
	if not(self.canJump) then
      if self.ySpeed < 0 then
          self.state = "jump"
      elseif self.ySpeed > 0 then
          self.state = "fall"
      end
  else
      if self.xSpeed > 0 then
          self.state = "moveRight"
      elseif self.xSpeed < 0 then
          self.state = "moveLeft"
      else
          self.state = "stand"
      end
  end
end

function player:getState()
    local state = ""
    if self.onFloor then
        if self.xSpeed > 0 then
            state = "moveRight"
        elseif self.xSpeed < 0 then
            state = "moveLeft"
        else
            state = "stand"
        end
    end
    if self.ySpeed < 0 then
        state = "jump"
    elseif self.ySpeed > 0 then
        state = "fall"
    end
    return state
end